# Minnesota
* We exclude part-year residents (line 13, form M1) and assume all residents are full-year
* We exclude lin 14 other taxes (M1HOME, Schedule M1529, and Schedule M1LS)
* We exclude contribution to Nongame Wildlife Fund (line 18, form M1)
* We exclude any code logic for Minnesota income tax withheld (line 20, form M1) and Minnesota estimated tax and extension payments (line 21, form M1)
